pub struct PassthroughFs<S: BitmapSlice + Send + Sync = ()> { /* private fields */ }Expand description
A file system that simply “passes through” all requests it receives to the underlying file system.
To keep the implementation simple it servers the contents of its root directory. Users that wish to serve only a specific directory should set up the environment so that that directory ends up as the root of the file system process. One way to accomplish this is via a combination of mount namespaces and the pivot_root system call.
Implementations
Sourceimpl<S: BitmapSlice + Send + Sync> PassthroughFs<S>
impl<S: BitmapSlice + Send + Sync> PassthroughFs<S>
Sourcepub async fn do_getattr_helper(
&self,
inode: Inode,
handle: Option<u64>,
) -> Result<(stat64, Duration)>
pub async fn do_getattr_helper( &self, inode: Inode, handle: Option<u64>, ) -> Result<(stat64, Duration)>
Internal getattr helper that skips ID mapping.
This helper is specifically designed for internal use by overlayfs. It calls
do_getattr_inner with mapping: false to retrieve the raw, unmodified host
attributes of a file. This is essential for the copy_up process to correctly
preserve the original file ownership.
Sourcepub async fn do_create_helper(
&self,
req: Request,
parent: Inode,
name: &OsStr,
mode: u32,
flags: u32,
uid: u32,
gid: u32,
) -> Result<ReplyCreated>
pub async fn do_create_helper( &self, req: Request, parent: Inode, name: &OsStr, mode: u32, flags: u32, uid: u32, gid: u32, ) -> Result<ReplyCreated>
A wrapper for create, used by copy_regfile_up.
This helper is called during a copy-up operation to create a file in the upper layer while preserving the original host UID/GID from the lower layer file.
Sourcepub async fn do_mkdir_helper(
&self,
req: Request,
parent: Inode,
name: &OsStr,
mode: u32,
umask: u32,
uid: u32,
gid: u32,
) -> Result<ReplyEntry>
pub async fn do_mkdir_helper( &self, req: Request, parent: Inode, name: &OsStr, mode: u32, umask: u32, uid: u32, gid: u32, ) -> Result<ReplyEntry>
A wrapper for mkdir, used by [create_upper_dir][crate::overlayfs::OverlayInode::create_upper_dir] function.
This helper is called during a copy-up operation when a parent directory needs to be created in the upper layer, preserving the original host UID/GID.
Sourcepub async fn do_symlink_helper(
&self,
req: Request,
parent: Inode,
name: &OsStr,
link: &OsStr,
uid: u32,
gid: u32,
) -> Result<ReplyEntry>
pub async fn do_symlink_helper( &self, req: Request, parent: Inode, name: &OsStr, link: &OsStr, uid: u32, gid: u32, ) -> Result<ReplyEntry>
A wrapper for symlink, used by copy_symlink_up function.
This helper is called during a copy-up operation to create a symbolic link in the upper layer while preserving the original host UID/GID from the lower layer link.
Sourceimpl<S: BitmapSlice + Send + Sync> PassthroughFs<S>
impl<S: BitmapSlice + Send + Sync> PassthroughFs<S>
Sourcepub fn new(cfg: Config) -> Result<PassthroughFs<S>>
pub fn new(cfg: Config) -> Result<PassthroughFs<S>>
Create a Passthrough file system instance.
Sourcepub fn keep_fds(&self) -> Vec<RawFd> ⓘ
pub fn keep_fds(&self) -> Vec<RawFd> ⓘ
Get the list of file descriptors which should be reserved across live upgrade.
Sourcepub async fn readlinkat_proc_file(&self, inode: u64) -> Result<PathBuf>
pub async fn readlinkat_proc_file(&self, inode: u64) -> Result<PathBuf>
Get the file pathname corresponding to the Inode This function is used by Nydus blobfs