Module util

Module util 

Structs

ScopedGid
ScopedUid
UniqueInodeGenerator
stat64

Constants

AT_EMPTY_PATH
SLASH_ASCII
ASCII for slash(‘/’)

Functions

convert_stat64_to_file_attr
ebadf
einval
enosys
eperm
filetype_from_mode
is_dir
Returns true if the mode is for a directory.
is_safe_inode
Returns true if it’s safe to open this inode without O_PATH.
openat
Safe wrapper around libc::openat().
osstr_to_cstr
reopen_fd_through_proc
Open /proc/self/fd/{fd} with the given flags to effectively duplicate the given fd with new flags (e.g. to turn an O_PATH file descriptor into one that can be used for I/O).
set_creds
stat64
stat_fd
validate_path_component
Validate a path component. A well behaved FUSE client should never send dot, dotdot and path components containing slash (‘/’). The only exception is that LOOKUP might contain dot and dotdot to support NFS export.