Structs
Constants
- AT_
EMPTY_ PATH - SLASH_
ASCII - ASCII for slash(‘/’)
Functions
- convert_
stat64_ to_ file_ attr - ebadf
- einval
- enosys
- eperm
- filetype_
from_ mode - is_dir
- Returns true if the mode is for a directory.
- is_
safe_ inode - Returns true if it’s safe to open this inode without O_PATH.
- openat
- Safe wrapper around libc::openat().
- osstr_
to_ cstr - reopen_
fd_ through_ proc - Open
/proc/self/fd/{fd}with the given flags to effectively duplicate the givenfdwith new flags (e.g. to turn anO_PATHfile descriptor into one that can be used for I/O). - set_
creds - stat64⚠
- stat_fd
- validate_
path_ component - Validate a path component. A well behaved FUSE client should never send dot, dotdot and path components containing slash (‘/’). The only exception is that LOOKUP might contain dot and dotdot to support NFS export.