Structs
Constants
- AT_
EMPTY_ PATH - SLASH_
ASCII - ASCII for slash(‘/’)
Functions
- convert_
stat64_ to_ file_ attr - ebadf
- einval
- enosys
- eperm
- fd_
path_ cstr - Return a C-string path that, when opened, refers to the same underlying file as
fd. - filetype_
from_ mode - is_dir
- Returns true if the mode is for a directory.
- is_
safe_ inode - Returns true if it’s safe to open this inode without O_PATH.
- join_
dir_ and_ name - Concatenate a directory C-string path and a single component C-string into
a NUL-terminated absolute path. Used by macOS callers (e.g.
renamex_np) that don’t have a dirfd-relative variant. - openat
- Safe wrapper around libc::openat().
- osstr_
to_ cstr - reopen_
fd_ through_ proc - Open
/proc/self/fd/{fd}with the given flags to effectively duplicate the givenfdwith new flags (e.g. to turn anO_PATHfile descriptor into one that can be used for I/O). - set_
creds - stat64⚠
- stat_fd
- validate_
path_ component - Validate a path component. A well behaved FUSE client should never send dot, dotdot and path components containing slash (‘/’). The only exception is that LOOKUP might contain dot and dotdot to support NFS export.